=======================
Making use of web tools
=======================

This tutorial will help you figure out how to add some interesting tools to
help you make best use of commonly available tools on internet.

This tutorial assume you already have a Pypi_ ready package. If not, check the
previous tutorials (:doc:pypi).

In the following, I will assume you have created a 'dvlpt' virtual environment
and that you activated it. Just forget about it if you are not using virtual
environments.

Travis-CT
=========

ReadTheDocs
===========

Landscape.io
============


.. _PyPi: https://pypi.python.org/pypi
